source("trunc_norm.r")

rho <- 0.95
lower <- c(-1,-1.5)
upper <- c(2.5,2)

postscript("norm1a.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 6
n_iters <- 250

cat("\nStandard Gibbs Sampling\n")
set.seed(seed)
res.gs <- vec_trunc_normal_gibbs ("s", n_chains, n_iters)
bi_plot(res.gs)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Standard Gibbs Sampling",side=2,padj=-3)
uni_plot(res.gs,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.gs))

cat("\nCoupled Gibbs Sampling\n")
set.seed(seed)
res.gc <- vec_trunc_normal_gibbs ("c", n_chains, n_iters)
bi_plot(res.gc)
mtext("Coupled Gibbs Sampling",side=2,padj=-3)
uni_plot(res.gc,1)
print(estimates(res.gc))

cat("\nPermutation Gibbs Sampling\n")
set.seed(seed)
res.gp <- vec_trunc_normal_gibbs ("p", n_chains, n_iters)
bi_plot(res.gp)
mtext("Permutation Gibbs Sampling",side=2,padj=-3)
uni_plot(res.gp,1)
print(estimates(res.gp))

dev.off()

postscript("norm1b.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 6
n_iters <- 250

cat("\nStandard Metropolis\n")
set.seed(seed)
res.ms <- vec_trunc_normal_met ("s", n_chains, n_iters)
bi_plot(res.ms)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Standard Metropolis",side=2,padj=-3)
uni_plot(res.ms,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.ms))

cat("\nCoupled Metropolis\n")
set.seed(seed)
res.mc <- vec_trunc_normal_met ("c", n_chains, n_iters)
bi_plot(res.mc)
mtext("Coupled Metropolis",side=2,padj=-3)
uni_plot(res.mc,1)
print(estimates(res.mc))

cat("\nPermutation Metropolis\n")
set.seed(seed)
res.mp <- vec_trunc_normal_met ("p", n_chains, n_iters)
bi_plot(res.mp)
mtext("Permutation Metropolis",side=2,padj=-3)
uni_plot(res.mp,1)
print(estimates(res.mp))

dev.off()

postscript("norm1c.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 100
n_iters <- 1000

cat("\nStandard Gibbs Sampling\n")
set.seed(seed)
res.gs <- vec_trunc_normal_gibbs ("s", n_chains, n_iters)
bi_plot(res.gs)
uni_plot(res.gs,1)
print(estimates(res.gs))

cat("\nCoupled Gibbs Sampling\n")
set.seed(seed)
res.gc <- vec_trunc_normal_gibbs ("c", n_chains, n_iters)
bi_plot(res.gc)
uni_plot(res.gc,1)
print(estimates(res.gc))

cat("\nPermutation Gibbs Sampling\n")
set.seed(seed)
res.gp <- vec_trunc_normal_gibbs ("p", n_chains, n_iters)
bi_plot(res.gp)
uni_plot(res.gp,1)
print(estimates(res.gp))

dev.off()

postscript("norm1d.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 100
n_iters <- 1000

cat("\nStandard Metropolis\n")
set.seed(seed)
res.ms <- vec_trunc_normal_met ("s", n_chains, n_iters)
bi_plot(res.ms)
uni_plot(res.ms,1)
print(estimates(res.ms))

cat("\nCoupled Metropolis\n")
set.seed(seed)
res.mc <- vec_trunc_normal_met ("c", n_chains, n_iters)
bi_plot(res.mc)
uni_plot(res.mc,1)
print(estimates(res.mc))

cat("\nPermutation Metropolis\n")
set.seed(seed)
res.mp <- vec_trunc_normal_met ("p", n_chains, n_iters)
bi_plot(res.mp)
uni_plot(res.mp,1)
print(estimates(res.mp))

dev.off()
