source("trunc_norm.r")

rho <- 0.95
lower <- c(-1,-1.5)
upper <- c(2.5,2)

postscript("norm2a.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 6
n_iters <- 250

cat("\nGibbs Sampling, Random Stream\n")
set.seed(seed)
res.g1 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters)
bi_plot(res.g1)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Gibbs Sampling, Random stream",side=2,padj=-3)
uni_plot(res.g1,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.g1))

s <- c (0.231, 0.452)
cat("\nGibbs Sampling, Repeating s =",s,"\n")
set.seed(seed)
res.g2 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters, s = matrix(s,n_iters,2))
bi_plot(res.g2)
mtext("Gibbs Sampling, Repeating 0.231, 0.452",side=2,padj=-3)
uni_plot(res.g2,1)
print(estimates(res.g2))

s <- 0.211
cat("\nGibbs Sampling, Repeating s =",s,"\n")
set.seed(seed)
res.g3 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters, s = matrix(s,n_iters,2))
bi_plot(res.g3)
mtext("Gibbs Sampling, Repeating 0.211",side=2,padj=-3)
uni_plot(res.g3,1)
print(estimates(res.g3))

dev.off()

postscript("norm2b.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 6
n_iters <- 250

cat("\nMetropolis, Random stream\n")
set.seed(seed)
res.m1 <- vec_trunc_normal_met ("p", n_chains, n_iters)
bi_plot(res.m1)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Metropolis, Random stream",side=2,padj=-3)
uni_plot(res.m1,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.m1))

s <- c (0.231, 0.452); delta <- c (0.6572, 0.2031, 0.0377, 0.8103)
cat("\nMetropolis, Repeating s =",s," delta =",delta,"\n")
set.seed(seed)
res.m2 <- vec_trunc_normal_met ("p", n_chains, n_iters,
            s = matrix(s,n_iters,2), delta=matrix(delta,n_iters,2))
bi_plot(res.m2)
mtext("Metropolis, Repeating 0.231, 0.452",side=2,padj=-3)
uni_plot(res.m2,1)
print(estimates(res.m2))

set.seed(seed)
s <- c(0.211, 0.707); delta <- sample(seq(0,1,length=2*n_iters))
cat("\nMetropolis, Repeating s =",s," delta = sample seq\n")
set.seed(seed)
res.m3 <- vec_trunc_normal_met ("p", n_chains, n_iters,
            s = matrix(s,n_iters,2), delta=matrix(delta,n_iters,2))
bi_plot(res.m3)
mtext("Metropolis, Repeating 0.211, 0.707",side=2,padj=-3)
uni_plot(res.m3,1)
print(estimates(res.m3))

dev.off()

postscript("norm2c.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 100
n_iters <- 1000

cat("\nGibbs Sampling, Random Stream\n")
set.seed(seed)
res.g1 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters)
bi_plot(res.g1)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Gibbs Sampling, Random stream",side=2,padj=-3)
uni_plot(res.g1,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.g1))

s <- c (0.231, 0.452)
cat("\nGibbs Sampling, Repeating s =",s,"\n")
set.seed(seed)
res.g2 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters, s = matrix(s,n_iters,2))
bi_plot(res.g2)
mtext("Gibbs Sampling, Repeating 0.231, 0.452",side=2,padj=-3)
uni_plot(res.g2,1)
print(estimates(res.g2))

s <- 0.211
cat("\nGibbs Sampling, Repeating s =",s,"\n")
set.seed(seed)
res.g3 <- vec_trunc_normal_gibbs ("p", n_chains, n_iters, s = matrix(s,n_iters,2))
bi_plot(res.g3)
mtext("Gibbs Sampling, Repeating 0.211",side=2,padj=-3)
uni_plot(res.g3,1)
print(estimates(res.g3))

dev.off()

postscript("norm2d.ps",pointsize=10,horizontal=FALSE,width=6,height=8.5)
par (mfrow=c(3,2), mar=c(3.3,3.9,2,1), mgp=c(1.9,0.7,0))

seed <- 1
n_chains <- 100
n_iters <- 1000

cat("\nMetropolis, Random stream\n")
set.seed(seed)
res.m1 <- vec_trunc_normal_met ("p", n_chains, n_iters)
bi_plot(res.m1)
title("Plot of x1 vs. x2",cex.main=1.5)
mtext("Metropolis, Random stream",side=2,padj=-3)
uni_plot(res.m1,1)
title("Trace plot of x1",cex.main=1.5)
print(estimates(res.m1))

s <- c (0.231, 0.452); delta <- c (0.6572, 0.2031, 0.0377, 0.8103)
cat("\nMetropolis, Repeating s =",s," delta =",delta,"\n")
set.seed(seed)
res.m2 <- vec_trunc_normal_met ("p", n_chains, n_iters,
            s = matrix(s,n_iters,2), delta=matrix(delta,n_iters,2))
bi_plot(res.m2)
mtext("Metropolis, Repeating 0.231, 0.452",side=2,padj=-3)
uni_plot(res.m2,1)
print(estimates(res.m2))

set.seed(seed)
s <- c(0.211, 0.707); delta <- sample(seq(0,1,length=2*n_iters))
cat("\nMetropolis, Repeating s =",s," delta = sample seq\n")
set.seed(seed)
res.m3 <- vec_trunc_normal_met ("p", n_chains, n_iters,
            s = matrix(s,n_iters,2), delta=matrix(delta,n_iters,2))
bi_plot(res.m3)
mtext("Metropolis, Repeating 0.211, 0.707",side=2,padj=-3)
uni_plot(res.m3,1)
print(estimates(res.m3))

dev.off()
